@@ -6,7 +6,7 @@
 ######## NOT SETTINGS, JUST BOILER PLATE ##############
 import os
 
-VERSION = '0.2'
+VERSION = '0.3'
 ROOT_DIR = os.path.dirname(os.path.abspath(__file__))
 LIBS_DIR = os.path.join(os.path.dirname(ROOT_DIR), 'libs')
 
@@ -70,3 +70,8 @@ MENU = (
 # limit size of pasted text in bytes. Be careful allowing too much size can
 # slow down user's browser
 MAX_SIZE = 1024 * 500
+
+# length of base64-like paste-id string in the url, int from 4 to 27 (length of sha1 digest)
+# total number of unique pastes can be calculated as 2^(6*PASTE_ID_LENGTH)
+# for PASTE_ID_LENGTH=8, for example, it's 2^(6*8) = 281 474 976 710 656
+PASTE_ID_LENGTH = 8
